[java-opensaml] branch main updated: OSJ-318 - Deprecate terms from classes and configuration

Scott Cantor cantor.2 at osu.edu
Mon Oct 26 17:07:12 UTC 2020


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch main
in repository java-opensaml.

View the commit online:
http://git.shibboleth.net/view/?p=java-opensaml.git;a=commit;h=d429f309830499d21b3c060cbff4c26fc5b1c4d6

The following commit(s) were added to refs/heads/main by this push:
       new  d429f3098 OSJ-318 - Deprecate terms from classes and configuration
d429f3098 is described below

commit d429f309830499d21b3c060cbff4c26fc5b1c4d6
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Mon Oct 26 13:07:09 2020 -0400

    OSJ-318 - Deprecate terms from classes and configuration
    
    https://issues.shibboleth.net/jira/browse/OSJ-318
    
    Overlooked some logging and javadocs.
---
 .../org/opensaml/xmlsec/encryption/support/Decrypter.java  | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/opensaml-xmlsec-api/src/main/java/org/opensaml/xmlsec/encryption/support/Decrypter.java b/opensaml-xmlsec-api/src/main/java/org/opensaml/xmlsec/encryption/support/Decrypter.java
index 22868f7da..1883d4ddd 100644
--- a/opensaml-xmlsec-api/src/main/java/org/opensaml/xmlsec/encryption/support/Decrypter.java
+++ b/opensaml-xmlsec-api/src/main/java/org/opensaml/xmlsec/encryption/support/Decrypter.java
@@ -986,7 +986,7 @@ public class Decrypter {
      * Validate the algorithms contained within an {@link EncryptedKey}.
      * 
      * @param encryptedKey the encrypted key instance to validate
      * @throws DecryptionException if any algorithms do not satisfy whitelist/blacklist policy
      */
     protected void validateAlgorithms(@Nonnull final EncryptedKey encryptedKey) throws DecryptionException {
         final String encryptionAlgorithm = encryptedKey.getEncryptionMethod().getAlgorithm();
@@ -1027,25 +1027,25 @@ public class Decrypter {
      * Validate the algorithms contained within an {@link EncryptedData}.
      * 
      * @param encryptedData the encrypted data instance to validate
      * @throws DecryptionException if any algorithms do not satisfy whitelist/blacklist policy
      */
     protected void validateAlgorithms(@Nonnull final EncryptedData encryptedData) throws DecryptionException {
         validateAlgorithmURI(encryptedData.getEncryptionMethod().getAlgorithm());
     }
     
     /**
      * Validate the supplied algorithm URI against the configured whitelist and blacklist.
      * 
      * @param algorithmURI the algorithm URI to evaluate
      * @throws DecryptionException if the algorithm URI does not satisfy the whitelist/blacklist policy
      */
     protected void validateAlgorithmURI(@Nonnull final String algorithmURI) throws DecryptionException {
-        log.debug("Validating algorithm URI against whitelist and blacklist: "
-                + "algorithm: {}, whitelist: {}, blacklist: {}",
+        log.debug("Validating algorithm URI against include and exclude lists: "
+                + "algorithm: {}, included: {}, excluded: {}",
                 algorithmURI, includedAlgorithmURIs, excludedAlgorithmURIs);
         
         if (!AlgorithmSupport.validateAlgorithmURI(algorithmURI, includedAlgorithmURIs, excludedAlgorithmURIs)) {
-            throw new DecryptionException("Algorithm failed whitelist/blacklist validation: " + algorithmURI);
+            throw new DecryptionException("Algorithm failed include/exclude validation: " + algorithmURI);
         }
         
     }
@@ -986,7 +986,7 @@ public class Decrypter {
      * 
      * @param encryptedKey the encrypted key instance to validate
-     * @throws DecryptionException if any algorithms do not satisfy whitelist/blacklist policy
+     * @throws DecryptionException if any algorithms do not satisfy include/exclude policy
      */
     protected void validateAlgorithms(@Nonnull final EncryptedKey encryptedKey) throws DecryptionException {
@@ -1027,25 +1027,25 @@ public class Decrypter {
      * 
      * @param encryptedData the encrypted data instance to validate
-     * @throws DecryptionException if any algorithms do not satisfy whitelist/blacklist policy
+     * @throws DecryptionException if any algorithms do not satisfy include/exclude policy
      */
     protected void validateAlgorithms(@Nonnull final EncryptedData encryptedData) throws DecryptionException {
@@ -1027,25 +1027,25 @@ public class Decrypter {
     
     /**
-     * Validate the supplied algorithm URI against the configured whitelist and blacklist.
+     * Validate the supplied algorithm URI against the configured include and exclude lists.
      * 
      * @param algorithmURI the algorithm URI to evaluate
@@ -1027,25 +1027,25 @@ public class Decrypter {
      * 
      * @param algorithmURI the algorithm URI to evaluate
-     * @throws DecryptionException if the algorithm URI does not satisfy the whitelist/blacklist policy
+     * @throws DecryptionException if the algorithm URI does not satisfy the include/exclude policy
      */
     protected void validateAlgorithmURI(@Nonnull final String algorithmURI) throws DecryptionException {

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list